/*
 * $Id: date.c,v 1.5 1998/06/14 21:18:32 gregm Exp $
 * GXSNMP - An snmp managment application
 * Copyright (C) 1998 Gregory McLean
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 * Some generic date conversion type routines.
 */

#ifndef lint
static char const copyright[] =
"@(#) Copyright (C) 1998 Gregory McLean";
#endif
static char const rcsid[] =
"$Id: date.c,v 1.5 1998/06/14 21:18:32 gregm Exp $";

#include "main.h"

char *
db_time_str (char *buf)
{
  struct tm     *tim;
  time_t        gm_time;

  gm_time = time (NULL);
  tim     = localtime (&gm_time);
  strftime (buf, sizeof (buf), "%Y%m%d%H%M%S", tim);
  return buf;
}
/* EOF */







